@@ -14,6 +14,7 @@ from __future__ import division
 
 import warnings
 from abc import ABCMeta, abstractmethod
+import sys
 
 import six
 from six.moves import zip
@@ -22,7 +23,7 @@ from six.moves.urllib.parse import (
 
 import furl
 from furl.omdict1D import omdict1D
-from furl.compat import OrderedDict as odict
+from furl.compat import string_types, OrderedDict as odict
 
 import unittest
 
@@ -115,6 +116,17 @@ class itemstr(str, itemcontainer):
         return str(self)
 
 
+class TestMetadata(unittest.TestCase):
+    def test_metadata(self):
+        assert furl.__title__
+        assert furl.__version__
+        assert furl.__license__
+        assert furl.__author__
+        assert furl.__contact__
+        assert furl.__url__
+        assert furl.__description__
+
+
 class TestPath(unittest.TestCase):
 
     def test_none(self):
@@ -548,6 +560,13 @@ class TestPath(unittest.TestCase):
         p4 = furl.Path('f')
         assert p3 / p4 == furl.Path('e/f')
 
+        # Joining paths with __truediv__ should not modify the original, even
+        # if <isabsolute> is True.
+        p5 = furl.Path(['a', 'b'], force_absolute=lambda _: True)
+        p6 = p5 / 'c'
+        assert str(p5) == '/a/b'
+        assert str(p6) == '/a/b/c'
+
     def test_asdict(self):
         segments = ['wiki', 'ロリポップ']
         path_encoded = 'wiki/%E3%83%AD%E3%83%AA%E3%83%9D%E3%83%83%E3%83%97'
@@ -602,17 +621,17 @@ class TestQuery(unittest.TestCase):
             'space=a+a&amp=a%26a', 'a a=a a&no encoding=sup', 'a+a=a+a',
             'a%20=a+a', 'a%20a=a%20a', 'a+a=a%20a', 'space=a a&amp=a^a',
             'a=a&s=s#s', '+=+', "/?:@-._~!$&'()*+,=/?:@-._~!$'()*+,=",
-            'a=a&c=c%5Ec', '<=>&^="', '%3C=%3E&%5E=%22', '%=%;`=`',
+            'a=a&c=c%5Ec', '<=>&^="', '%3C=%3E&%5E=%22', '%=%&`=`',
             '%25=%25&%60=%60',
             # Only keys, no values.
             'asdfasdf', '/asdf/asdf/sdf', '*******', '!@#(*&@!#(*@!#', 'a&b',
-            'a;b',
+            'a&b',
             # Repeated parameters.
             'a=a&a=a', 'space=a+a&space=b+b',
             # Empty keys and/or values.
             '=', 'a=', 'a=a&a=', '=a&=b',
-            # Semicolon delimiter, like 'a=a;b=b'.
-            'a=a;a=a', 'space=a+a;space=b+b',
+            # Semicolon delimiter is not allowed per default after bpo#42967
+            'a=a&a=a', 'space=a+a&space=b+b',
         ]))
         self.items = (self.itemlists + self.itemdicts + self.itemomdicts +
                       self.itemstrs)
@@ -1956,6 +1975,14 @@ class TestFurl(unittest.TestCase):
                              username=True, password=True, port=True)
         assert f.url == 'http://host/a/big/?s=s+s'
 
+        # scheme, host, port, netloc, origin.
+        f = furl.furl('https://host:999/path')
+        assert f.copy().remove(scheme=True).url == '//host:999/path'
+        assert f.copy().remove(host=True).url == 'https://:999/path'
+        assert f.copy().remove(port=True).url == 'https://host/path'
+        assert f.copy().remove(netloc=True).url == 'https:///path'
+        assert f.copy().remove(origin=True).url == '/path'
+
         # No errors are thrown when removing URL components that don't exist.
         f = furl.furl(url)
         assert f is f.remove(fragment_path=['asdf'], fragment_args=['asdf'],
@@ -2037,9 +2064,13 @@ class TestFurl(unittest.TestCase):
         assert f.url == 'http://pepp.ru/a/b/c#uwantpump?'
 
         # In edge cases (e.g. URLs without an authority/netloc), behave
-        # identically to urllib.parse.urljoin().
+        # identically to urllib.parse.urljoin(), which changed behavior in
+        # Python 3.9.
         f = furl.furl('wss://slrp.com/').join('foo:1')
-        assert f.url == 'wss://slrp.com/foo:1'
+        if sys.version_info[:2] < (3, 9):
+            assert f.url == 'wss://slrp.com/foo:1'
+        else:
+            assert f.url == 'foo:1'
         f = furl.furl('wss://slrp.com/').join('foo:1:rip')
         assert f.url == 'foo:1:rip'
         f = furl.furl('scheme:path').join('foo:blah')
@@ -2355,3 +2386,17 @@ class TestFurl(unittest.TestCase):
             'fragment': f.asdict(),
             }
         assert u.asdict() == d
+
+
+class TestMeta(unittest.TestCase):
+    def test_metadata_varibles(self):
+        def is_non_empty_string(s):
+            return isinstance(s, string_types) and s
+
+        assert is_non_empty_string(furl.__title__)
+        assert is_non_empty_string(furl.__version__)
+        assert is_non_empty_string(furl.__license__)
+        assert is_non_empty_string(furl.__author__)
+        assert is_non_empty_string(furl.__contact__)
+        assert is_non_empty_string(furl.__url__)
+        assert is_non_empty_string(furl.__description__)
